==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/security/v1beta1/RuleFromFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RuleFromFluentImpl<A extends RuleFromFluent<A>> extends BaseFluent<A> implements RuleFromFluent<A>{
  public RuleFromFluentImpl() {
  }
  public RuleFromFluentImpl(RuleFrom instance) {
    this.withSource(instance.getSource()); 
  }
  private SourceBuilder source;
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public Source getSource() {
    return this.source!=null ?this.source.build():null;
  }
  public Source buildSource() {
    return this.source!=null ?this.source.build():null;
  }
  public A withSource(Source source) {
    _visitables.get("source").remove(this.source);
    if (source!=null){ this.source= new SourceBuilder(source); _visitables.get("source").add(this.source);} else { this.source = null; _visitables.get("source").remove(this.source); } return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public RuleFromFluent.SourceNested<A> withNewSource() {
    return new RuleFromFluentImpl.SourceNestedImpl();
  }
  public RuleFromFluent.SourceNested<A> withNewSourceLike(Source item) {
    return new RuleFromFluentImpl.SourceNestedImpl(item);
  }
  public RuleFromFluent.SourceNested<A> editSource() {
    return withNewSourceLike(getSource());
  }
  public RuleFromFluent.SourceNested<A> editOrNewSource() {
    return withNewSourceLike(getSource() != null ? getSource(): new SourceBuilder().build());
  }
  public RuleFromFluent.SourceNested<A> editOrNewSourceLike(Source item) {
    return withNewSourceLike(getSource() != null ? getSource(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RuleFromFluentImpl that = (RuleFromFluentImpl) o;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(source,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  class SourceNestedImpl<N> extends SourceFluentImpl<RuleFromFluent.SourceNested<N>> implements RuleFromFluent.SourceNested<N>,Nested<N>{
    SourceNestedImpl(Source item) {
      this.builder = new SourceBuilder(this, item);
    }
    SourceNestedImpl() {
      this.builder = new SourceBuilder(this);
    }
    SourceBuilder builder;
    public N and() {
      return (N) RuleFromFluentImpl.this.withSource(builder.build());
    }
    public N endSource() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/RuleFromFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RuleFromFluentImpl<A extends RuleFromFluent<A>> extends BaseFluent<A> implements RuleFromFluent<A>{
  public RuleFromFluentImpl() {
  }
  public RuleFromFluentImpl(RuleFrom instance) {
    if (instance != null) {
      this.withSource(instance.getSource());
    }
  }
  private SourceBuilder source;
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public Source getSource() {
    return this.source!=null ?this.source.build():null;
  }
  public Source buildSource() {
    return this.source!=null ?this.source.build():null;
  }
  public A withSource(Source source) {
    _visitables.get("source").remove(this.source);
    if (source!=null){ this.source= new SourceBuilder(source); _visitables.get("source").add(this.source);} else { this.source = null; _visitables.get("source").remove(this.source); } return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public RuleFromFluentImpl.SourceNested<A> withNewSource() {
    return new RuleFromFluentImpl.SourceNestedImpl();
  }
  public RuleFromFluentImpl.SourceNested<A> withNewSourceLike(Source item) {
    return new RuleFromFluentImpl.SourceNestedImpl(item);
  }
  public RuleFromFluentImpl.SourceNested<A> editSource() {
    return withNewSourceLike(getSource());
  }
  public RuleFromFluentImpl.SourceNested<A> editOrNewSource() {
    return withNewSourceLike(getSource() != null ? getSource(): new SourceBuilder().build());
  }
  public RuleFromFluentImpl.SourceNested<A> editOrNewSourceLike(Source item) {
    return withNewSourceLike(getSource() != null ? getSource(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RuleFromFluentImpl that = (RuleFromFluentImpl) o;
    if (!java.util.Objects.equals(source, that.source)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(source,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (source != null) { sb.append("source:"); sb.append(source); }
    sb.append("}");
    return sb.toString();
  }
  class SourceNestedImpl<N> extends SourceFluentImpl<RuleFromFluentImpl.SourceNested<N>> implements RuleFromFluentImpl.SourceNested<N>,Nested<N>{
    SourceNestedImpl(Source item) {
      this.builder = new SourceBuilder(this, item);
    }
    SourceNestedImpl() {
      this.builder = new SourceBuilder(this);
    }
    SourceBuilder builder;
    public N and() {
      return (N) RuleFromFluentImpl.this.withSource(builder.build());
    }
    public N endSource() {
      return and();
    }
    
  }
  
}
